@@ -179,7 +179,7 @@ class Benchmark(FunctionNode[Experiment, Experiment]):
 def construct_benchmark_for(
     sampler: JijZeptBaseSampler,
     models: list[tuple[jm.Problem, jm.PH_VALUES_INTERFACE]],
-    params: dict[str, tp.Iterable],
+    params: dict[str, tp.Iterable[tp.Any]],
     name: str | None = None,
 ) -> Benchmark:
     """Create a Benchmark object.
