@@ -17,7 +17,7 @@ from jijbench.functions.concat import Concat
 from jijbench.functions.factory import ArtifactFactory, TableFactory
 from jijbench.io.io import save
 from jijbench.solver.base import Parameter, Response
-from jijbench.typing import ExperimentDataType
+from jijbench.typing import ArtifactDataType, ExperimentDataType
 
 
 @dataclass
@@ -86,7 +86,7 @@ class Experiment(Container[ExperimentDataType]):
         setattr(self, "state", _Waiting(self.name))
 
     @property
-    def artifact(self) -> dict:
+    def artifact(self) -> ArtifactDataType:
         """Return the artifact of the experiment as a dictionary."""
         return self.data[0].view()
 
@@ -109,10 +109,11 @@ class Experiment(Container[ExperimentDataType]):
         return self.table[bools].dropna(axis=1)
 
     @property
-    def returns_table(self) -> pd.DataFrame:
+    def response_table(self) -> pd.DataFrame:
         """Return the returns table of the experiment as a pandas dataframe."""
-        bools = self.data[1].data.applymap(lambda x: isinstance(x, Response))
-        return self.table[bools].dropna(axis=1)
+        bools = self.data[1].data.apply(lambda x: not isinstance(x[0], Response))
+        droped_columns = self.data[1].data.columns[bools]
+        return self.table.drop(columns=droped_columns)
 
     @classmethod
     def validate_data(cls, data: ExperimentDataType) -> ExperimentDataType:
@@ -122,9 +123,7 @@ class Experiment(Container[ExperimentDataType]):
             data (ExperimentDataType): The data to validate.
 
         Raises:
-            TypeError: If data is not an instance of ExperimentDataType or
-            if the first element of data is not an instance of Artifact or
-            if the second element of data is not an instance of Table.
+            TypeError: If data is not an instance of ExperimentDataType or if the first element of data is not an instance of Artifact or if the second element of data is not an instance of Table.
 
         Returns:
             ExperimentDataType: The validated data.
